@@ -18,7 +18,7 @@ class SOAPServiceDescriptor(ServiceDescriptor):
 	xsd_type_map = type_to_xsd
 	_content_type = 'text/xml'
 	
-	def generate(self,servicename,servicenumber,typemanager,methodlist,service_url,encoding):
+	def generate(self,servicename,servicenumber,typemanager,methodlist,service_url,encoding,**kw):
 		"""
 		Generate WSDL file for DocumentLiteralSOAPInterface
 		"""
@@ -789,7 +789,7 @@ class DocumentLiteralSOAPInterface(BaseInterface):
 
 	@staticmethod
 	def _interface_name():
-		return 'soap'
+		return 'soapdocumentliteral'
 
 	@staticmethod
 	def _accept_basetype(typ):
