@@ -15,7 +15,7 @@ class SOAP11ServiceDescriptor(ServiceDescriptor):
 	xsd_type_map = type_to_xsd
 	_content_type = 'text/xml'
 	
-	def generate(self,servicename,servicenumber,typemanager,methodlist,service_url,encoding):
+	def generate(self,servicename,servicenumber,typemanager,methodlist,service_url,encoding,**kw):
 		"""
 		Generate WSDL file for SOAP11Interface
 		"""
