@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
+from ladon.compat import PORTABLE_STRING
 import inspect,ast,re,pprint,sys,copy
 from ladon.exceptions.ladonizer import *
 import ladon.interfaces as interfaces
 from ladon.types.ladontype import LadonType
 from ladon.types import validate_type
 from ladon.types.typemanager import TypeManager
+from ladon.types.tasktype import TaskInfoResponse
 
 # python2/3 support:
 if sys.version_info[0]==2:
@@ -17,8 +19,6 @@ elif sys.version_info[0]>=3:
 	def get_function_name(f):
 		return f.__name__
 
-
-
 class LadonServiceCollection(object):
 	
 	"""
@@ -324,7 +324,10 @@ class LadonServiceInfo(object):
 		"""
 		method = LadonMethodInfo(self,f,*def_args,**def_kw)
 		# store the method info
-		self.methods[get_function_name(f)] = method
+		if 'override_method_name' in def_kw:
+			self.methods[def_kw.get('override_method_name')] = method
+		else:
+			self.methods[get_function_name(f)] = method
 		return method
 	
 	def method(self,methodname):
@@ -473,8 +476,13 @@ class LadonMethodInfo(object):
 		self._defaults = argspecs.defaults
 		# Store the raw doc-string in _doc
 		self._doc = f.__doc__
-		# Extract the method name
-		self._func_name = get_function_name(f)
+		# Method name
+		if 'override_method_name' in def_kw:
+			# Method name override (on deferred method attachment)
+			self._func_name = def_kw.get('override_method_name')
+		else:
+			# Extract the method name
+			self._func_name = get_function_name(f)
 		# Store the parameter types delivered by the user via the ladonize decorator
 		self._arg_types = def_args
 		self._real_method = f
@@ -489,14 +497,21 @@ class LadonMethodInfo(object):
 		# unsafe convertions or not. An example of an unsafe convertion is float to int.
 		# unsafe convertions are disabled by default
 		self._allow_unsafe_conversion = False
+		# Check if the method is registered as a tasktype
+		self._tasktype = def_kw.get('tasktype',False)
+		#if self._tasktype:
+			#self.taskProgress = types.MethodType(taskProgress, self)
+			#self.taskResult = types.MethodType(taskResult, self)
 		# _rtype: The return type of the method.
 		try:
 			self._rtype = def_kw['rtype']
 		except KeyError as ke:
 			# return type must be specified.
 			raise ReturnTypeUndefined(sinfo,self._func_name)
-		# Check if the method is registered as a tasktype
-		self._tasktype = def_kw.get('tasktype',False)
+		if self._tasktype:
+			self._task_rtype = self._rtype
+			self._rtype = TaskInfoResponse
+			self._has_keywords = True
 		# _rtype_doc: Initialize the return type doc-string container
 		self._rtype_doc = []
 		# overwrite the default values of user options if they are passed on via the
@@ -637,7 +652,7 @@ class LadonMethodInfo(object):
 		"""
 		Serialize this method
 		"""
-		return {'methodname':self.name(),'doc':self.__doc__,'args':self.args(),'rtype':self._rtype, 'rtype_doc':self._rtype_doc}
+		return {'methodname':self.name(),'doc':self.__doc__,'args':self.args(),'rtype':self._rtype, 'rtype_doc':self._rtype_doc, 'task_rtype': getattr(self,'_task_rtype',None)}
 
 	def get_real_method(self):
 		"""
